@@ -2,11 +2,14 @@ from delta_lake.DataLake import DataLake
 from delta.tables import DeltaTable
 
 class Bronze(DataLake):
-
+    storage_bronze = None
     def __init__(self, spark, storage_account_name, storage_account_access_key, storage_landing, storage_bronze,
-                 input_data_param, mount_data_param, colums_validate_merge_param, new_name, database, target, origin):
+                 storage_silver, input_data_param, mount_data_param, colums_validate_merge_param, new_name, database,
+                 target, origin):
+        self.storage_bronze = storage_bronze
         super().__init__(spark, storage_account_name, storage_account_access_key, storage_landing, storage_bronze,
-                 input_data_param, mount_data_param, colums_validate_merge_param, new_name, database, target, origin)
+                         storage_silver, input_data_param, mount_data_param, colums_validate_merge_param, new_name,
+                         database, target, origin)
         self.initialize_variables()
 
 
